@@ -15,14 +15,16 @@ void YiffShortenBuffer16(
 	int buf_shoren_len
 );
 void YiffShortenBuffer8(
-        u_int8_t *buf,
-        int buf_len,		/* In u_int8_t units. */
-        int buf_shoren_len
+	u_int8_t *buf,
+	int buf_len,		/* In u_int8_t units. */
+	int buf_shoren_len
 );
 
 
-#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
-#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
 
 
 /*
@@ -31,25 +33,25 @@ void YiffShortenBuffer8(
  */
 void YiffMixBuffers(
 	Audio *audio,
-        SoundBuffer *tar_buf, const SoundBuffer *src_buf,
-        YDataLength len,
+	SoundBuffer *tar_buf, const SoundBuffer *src_buf,
+	YDataLength len,
 	Coefficient volume_left,
-        Coefficient volume_right
+	Coefficient volume_right
 ) 
 {
-        int i, b, blocks;
-        SoundBuffer *tp;
+	int i, b, blocks;
+	SoundBuffer *tp;
 	const SoundBuffer *sp;
 	Coefficient lc, rc;
 	Boolean flip;
 
    
-        if((audio == NULL) ||
-           (tar_buf == NULL) ||
-           (src_buf == NULL) ||
-           (len <= 0)
-        )
-            return;
+	if((audio == NULL) ||
+	   (tar_buf == NULL) ||
+	   (src_buf == NULL) ||
+	   (len <= 0)
+	)
+	    return;
 
 	flip = audio->flip_stereo;
 
@@ -61,7 +63,7 @@ void YiffMixBuffers(
 
 	    /* Calculate left and right coefficients. */
 	    lc = MAX(MIN(volume_left, 1), 0);
-            rc = MAX(MIN(volume_right, 1), 0);
+	    rc = MAX(MIN(volume_right, 1), 0);
 	}
 	else
 	{
@@ -71,55 +73,53 @@ void YiffMixBuffers(
 	    /* Average left and right coefficients. */
 	    lc = (volume_left + volume_right) / 2;
 
-            rc = MAX(MIN(lc, 1), 0);
+	    rc = MAX(MIN(lc, 1), 0);
 	    lc = rc;
 	}
 
 	/* Begin buffer mixing. */
-        for(i = 0, b = 0, tp = tar_buf, sp = src_buf;
-            i < len;
-            i++, tp++, sp++
-        ) 
-        {
+	for(i = 0, b = 0, tp = tar_buf, sp = src_buf;
+	    i < len;
+	    i++, tp++, sp++
+	) 
+	{
 	    /* Is source byte positive or negative? */
-            if(*sp < 0)
-            {
+	    if(*sp < 0)
+	    {
 		/* Source byte is negative. */
 
 		if(b == 0)
-                    (*tp) = MAX((int)(*tp) +
-                        ((int)(*sp) * ((flip) ? rc : lc)),
+		    (*tp) = MAX((int)(*tp) +
+			((int)(*sp) * ((flip) ? rc : lc)),
 			(int)-128
 		    );
 		else
 		    (*tp) = MAX((int)(*tp) +
-                        ((int)(*sp) * ((flip) ? lc : rc)),
+			((int)(*sp) * ((flip) ? lc : rc)),
 			(int)-128
 		    );
-            }
-            else
-            {
+	    }
+	    else
+	    {
 		/* Source byte is positive. */
 
-                if(b == 0)
-                    (*tp) = MIN((int)(*tp) +
-                        ((int)(*sp) * ((flip) ? rc : lc)),
+		if(b == 0)
+		    (*tp) = MIN((int)(*tp) +
+			((int)(*sp) * ((flip) ? rc : lc)),
 			(int)127
 		    );
 		else
-                    (*tp) = MIN((int)(*tp) +
-                        ((int)(*sp) * ((flip) ? lc : rc)),
+		    (*tp) = MIN((int)(*tp) +
+			((int)(*sp) * ((flip) ? lc : rc)),
 			(int)127
 		    );
-            }
+	    }
 
 	    /* Increment block position b. */
-            b++;
-            if(b >= blocks)
-                b = 0;
-        }
-
-        return;
+	    b++;
+	    if(b >= blocks)
+		b = 0;
+	}
 }
 
 /*
@@ -140,17 +140,15 @@ void YiffShortenBuffer16(
 			*src_ptr = buf,
 			*tar_end = buf + (buf_shoren_len / 2);
 
-        int	src_pos = 0,	/* Pos and inc in units of * 256. */
+	int	src_pos = 0,	/* Pos and inc in units of * 256. */
 		src_inc = 256 * buf_len / buf_shoren_len;
 
-        /* Target length is assumed to be shorter than source len. */
-        while(tar_ptr < tar_end)
-        {
-            *tar_ptr++ = src_ptr[(src_pos >> 8)];
-            src_pos += src_inc;
-        }                
-
-	return;
+	/* Target length is assumed to be shorter than source len. */
+	while(tar_ptr < tar_end)
+	{
+	    *tar_ptr++ = src_ptr[(src_pos >> 8)];
+	    src_pos += src_inc;
+	}                
 }
 
 /*
@@ -178,6 +176,4 @@ void YiffShortenBuffer8(
 	    *tar_ptr++ = src_ptr[(src_pos >> 8)];
 	    src_pos += src_inc;
 	}
-
-	return;
 }
