@@ -1,24 +1,30 @@
 #ifndef CONFIG_H
 #define CONFIG_H
 
+
+/*
+ *	Language:
+ */
+#define PROG_LANGUAGE_ENGLISH	1
+
+
 /*
  *	Default YIFF Sound Server configuration file location:
  *
  *	Full path to the YIFF Sound Server configuration file, it
- *	can also be specified from the command line at run time.
+ *	can also be specified from the command line at run time
  */
-#define DEF_RCFILE_NAME         "/usr/etc/yiffrc"
-/* Alternate name */
-/*
-#define DEF_RCFILE_NAME		"/usr/etc/YIFFConfig"
-*/
+#define DEF_RCFILE_NAME		"/usr/etc/yiffrc"
+/* #define DEF_RCFILE_NAME	"/etc/yiff.conf" */
+/* #define DEF_RCFILE_NAME	"/usr/etc/YIFFConfig" */
+
 
 /*
  *	Default Y mixer device channel settings file:
  *
  *	This file is stored in the user's home directory.
  */
-#define DEF_RCMIXERFILE_NAME         ".YMixerSettings"
+#define DEF_RCMIXERFILE_NAME	".YMixerSettings"
 
 
 /*
