@@ -10,6 +10,7 @@
 #ifndef PLAYSTACK_H
 #define PLAYSTACK_H
 
+#include <sys/types.h>
 #include "afw.h"
 #include "ytypes.h"
 
@@ -76,8 +77,8 @@ typedef struct {
 	int total_repeats;
 
 	/* Volume (for DSP type sound objects only). */
-	Coefficient	volume_left,
-			volume_right;
+	Coefficient	volume_left, volume_right,
+			volume_back_left, volume_back_right;
 
 } PlayStack;
 
