@@ -26,6 +26,12 @@ int VocReadPartialData(
 );
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Procedure to open a voc file and return its entire file size.
  */
@@ -34,40 +40,40 @@ static FILE *VocOpenFile(
 )
 {
 
-        FILE *fp;
-        struct stat stat_buf;
+	FILE *fp;
+	struct stat stat_buf;
 
 
-        if(filename == NULL)
-        {
-            fprintf(stderr, "Cannot open file with no name.\n");
-            *size_rtn = 0;
-            return(NULL);
-        }
-        if(mode == NULL)
-        {
-            fprintf(stderr, "%s: Open mode not givin.\n", filename);
-            *size_rtn = 0;
-            return(NULL);
-        }
+	if(filename == NULL)
+	{
+	    fprintf(stderr, "Cannot open file with no name.\n");
+	    *size_rtn = 0;
+	    return(NULL);
+	}
+	if(mode == NULL)
+	{
+	    fprintf(stderr, "%s: Open mode not givin.\n", filename);
+	    *size_rtn = 0;
+	    return(NULL);
+	}
 
-        if(stat(filename, &stat_buf))
-        {
-            fprintf(stderr, "%s: No such file.\n", filename);
-            *size_rtn = 0;
-            return(NULL);
-        }
-        *size_rtn = stat_buf.st_size;
+	if(stat(filename, &stat_buf))
+	{
+	    fprintf(stderr, "%s: No such file.\n", filename);
+	    *size_rtn = 0;
+	    return(NULL);
+	}
+	*size_rtn = stat_buf.st_size;
 
-        fp = fopen(filename, mode);
-        if(fp == NULL)
-        {
-            fprintf(stderr, "%s: Cannot open.\n", filename);
-            *size_rtn = 0;
-            return(NULL);
-        }
+	fp = fopen(filename, mode);
+	if(fp == NULL)
+	{
+	    fprintf(stderr, "%s: Cannot open.\n", filename);
+	    *size_rtn = 0;
+	    return(NULL);
+	}
 
-        return(fp);
+	return(fp);
 }
 
 /*
@@ -85,8 +91,8 @@ int VocIsFileVoc(const char *filename)
 	fp = VocOpenFile(filename, "rb", &filesize);
 	if(fp == NULL)
 	    return(VocErrorNoAccess);
-        if(filesize == 0)
-            return(VocErrorNoAccess);
+	if(filesize == 0)
+	    return(VocErrorNoAccess);
 
 	/* Bytes 0x00 to 0x13: Get magic name. */
 	for(i = 0; i < 0x13; i++)
@@ -123,8 +129,8 @@ unsigned int VocGetEnvSampleRate(voc_data_struct *vd)
 
 	/* Go through each data block. */
 	for(i = 0, ptr = vd->datablock;
-            i < vd->total_datablocks;
-            i++, ptr++)
+	    i < vd->total_datablocks;
+	    i++, ptr++)
 	{
 	    block_ptr = *ptr;
 	    if(block_ptr == NULL)
@@ -160,8 +166,8 @@ void VocDestroyData(voc_data_struct *vd)
 
 	/* Data blocks. */
 	for(i = 0, ptr = vd->datablock;
-            i < vd->total_datablocks;
-            i++, ptr++
+	    i < vd->total_datablocks;
+	    i++, ptr++
 	)
 	{
 	    block_ptr = *ptr;
@@ -190,15 +196,15 @@ void VocDestroyData(voc_data_struct *vd)
 	    vd->fp = NULL;
 	}
 
-        free(vd->data);
+	free(vd->data);
 	vd->data = NULL;
-        vd->data_len = 0;
+	vd->data_len = 0;
 
 	vd->total_data_len = 0;
 
 	vd->major_version = 0;
-        vd->minor_version = 0;
-        vd->first_data_block = 0;
+	vd->minor_version = 0;
+	vd->first_data_block = 0;
 
 
 	return;
@@ -277,46 +283,46 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 	off_t filesize;
 
 
-        /* Error checks. */
-        if(vd == NULL)
-            return(VocErrorNoBuffers);
-        if(fp == NULL)
-            return(VocErrorBadValue);
+	/* Error checks. */
+	if(vd == NULL)
+	    return(VocErrorNoBuffers);
+	if(fp == NULL)
+	    return(VocErrorBadValue);
 
-        /* Rewind to beginning of voc file. */
-        rewind(fp);
+	/* Rewind to beginning of voc file. */
+	rewind(fp);
 
 
 	/* Reset values. */
-        memset(vd, 0x00, sizeof(voc_data_struct));
+	memset(vd, 0x00, sizeof(voc_data_struct));
 
-        /* Get size of file. */
-        if(fstat(fileno(fp), &stat_buf))
-            return(VocErrorNoAccess);
+	/* Get size of file. */
+	if(fstat(fileno(fp), &stat_buf))
+	    return(VocErrorNoAccess);
 
-        filesize = stat_buf.st_size;
-        if(filesize == 0)
-            return(VocErrorNoAccess);
+	filesize = stat_buf.st_size;
+	if(filesize == 0)
+	    return(VocErrorNoAccess);
 
-        /* Is this is a voc file? Check 0x00 to 0x12 for magic number. */
-        for(x = 0; x < 0x13; x++)
-        {
-            magicname[x] = (char)fgetc(fp);
-            bytes_read++;
-        }
-        magicname[0x13] = '\0';
-        /* Magic name does not match? If so then this is not a voc
+	/* Is this is a voc file? Check 0x00 to 0x12 for magic number. */
+	for(x = 0; x < 0x13; x++)
+	{
+	    magicname[x] = (char)fgetc(fp);
+	    bytes_read++;
+	}
+	magicname[0x13] = '\0';
+	/* Magic name does not match? If so then this is not a voc
 	 * file.
 	 */
-        if(strcmp(magicname, VocMagicName))
-            return(VocErrorNotVoc);
+	if(strcmp(magicname, VocMagicName))
+	    return(VocErrorNotVoc);
 
 
 	/* Begin reading voc file header. */
 
-        /* Record file name. */
-        if(filename != NULL)
-            vd->filename = strdup(filename);
+	/* Record file name. */
+	if(filename != NULL)
+	    vd->filename = strdup(filename);
 
 	/* Record file size. */
 	vd->filesize = filesize;
@@ -342,13 +348,13 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 
 
 	/* 0x18 to 0x19: Extended stuff. */
-        x = fgetc(fp);
-        y = fgetc(fp);
-        bytes_read += 2;
+	x = fgetc(fp);
+	y = fgetc(fp);
+	bytes_read += 2;
 
 
 	/* Move fp to start of first block. */
-        fseek(fp, vd->first_data_block, SEEK_SET);
+	fseek(fp, vd->first_data_block, SEEK_SET);
 	nextseek = ftell(fp);
 
 	while(nextseek < vd->filesize)
@@ -360,7 +366,7 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 	    bytes_read++;
 	    switch(type)
 	    {
-              case VocBlockTypeTerminator:
+	      case VocBlockTypeTerminator:
 		/* Allocate data block. */
 		y = VocAddDataBlock((voc_data_struct *)vd, type);
 		if(y < 0)
@@ -377,22 +383,22 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 
 	      case VocBlockTypeSoundData:
 		/* Allocate data block. */
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
 		/* Calculate and set data_start_pos. */
 		vd->datablock[y]->data_start_pos = nextseek + 6;
 
 		/* Get size. */
 		size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
 		bytes_read += 3;
 		vd->datablock[y]->size = size_x + (size_y << 8) +
 		    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
 		/* Get data_len. */
 		if((long)vd->datablock[y]->size >= 2)
@@ -420,21 +426,21 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 		    vd->datablock[y]->bits = 8;
 		    break;
 
-                  case 0x01:
-                    vd->datablock[y]->bits = 4;
-                    break;
+		  case 0x01:
+		    vd->datablock[y]->bits = 4;
+		    break;
 
-                  case 0x02:
-                    vd->datablock[y]->bits = 2.6;
-                    break;
+		  case 0x02:
+		    vd->datablock[y]->bits = 2.6;
+		    break;
 
-                  case 0x03:
-                    vd->datablock[y]->bits = 2;
-                    break;
+		  case 0x03:
+		    vd->datablock[y]->bits = 2;
+		    break;
 
-                  case 0x04:	/* Multi DAC, not standard */
-                    vd->datablock[y]->bits = 8;
-                    break;
+		  case 0x04:	/* Multi DAC, not standard */
+		    vd->datablock[y]->bits = 8;
+		    break;
 
 		  default:
 		    vd->datablock[y]->bits = 8;
@@ -446,73 +452,73 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 
 	      case VocBlockTypeSoundDataContinue:
 		/* Allocate data block. */
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
-                /* Calculate and set data_start_pos. */
-                vd->datablock[y]->data_start_pos = nextseek + 4;
-                    
-                /* Get size. */
-                size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
-                bytes_read += 3;
-                vd->datablock[y]->size = size_x + (size_y << 8) +
-                    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Calculate and set data_start_pos. */
+		vd->datablock[y]->data_start_pos = nextseek + 4;
+		    
+		/* Get size. */
+		size_x = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
+		bytes_read += 3;
+		vd->datablock[y]->size = size_x + (size_y << 8) +
+		    (size_z << 16);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
-                /* Get data_len. */
-                vd->datablock[y]->data_len = vd->datablock[y]->size;
-                break;
+		/* Get data_len. */
+		vd->datablock[y]->data_len = vd->datablock[y]->size;
+		break;
 
 
 	      case VocBlockTypeSilence:
-                /* Allocate data block. */  
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		/* Allocate data block. */  
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
-                /* Get size. */
-                size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
-                bytes_read += 3;
-                vd->datablock[y]->size = size_x + (size_y << 8) +
-                    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Get size. */
+		size_x = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
+		bytes_read += 3;
+		vd->datablock[y]->size = size_x + (size_y << 8) +
+		    (size_z << 16);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
 		/* Get silence length. */
 		fread(&(vd->datablock[y]->silence_length), 1, 2, fp);
 		bytes_read += 2;
 
 		/* Get sample rate. */
-                z = fgetc(fp);
+		z = fgetc(fp);
 		bytes_read++;
-                if(z >= 256)
-                    z = 255;
-                vd->datablock[y]->sample_rate = (unsigned int)(
-                    (double)(-1000000) / (double)(z - 256)
+		if(z >= 256)
+		    z = 255;
+		vd->datablock[y]->sample_rate = (unsigned int)(
+		    (double)(-1000000) / (double)(z - 256)
 		);
 		break;
 
 	      case VocBlockTypeMarker:
-                /* Allocate data block. */
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		/* Allocate data block. */
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
-                /* Get size. */
-                size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
-                bytes_read += 3;
-                vd->datablock[y]->size = size_x + (size_y << 8) +
-                    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Get size. */
+		size_x = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
+		bytes_read += 3;
+		vd->datablock[y]->size = size_x + (size_y << 8) +
+		    (size_z << 16);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
 		/* Get marker number. */
 		fread(&(vd->datablock[y]->marker_num), 1, 2, fp);
@@ -520,20 +526,20 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 		break;
 
 	      case VocBlockTypeASCII:
-                /* Allocate data block. */
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		/* Allocate data block. */
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
-                /* Get size. */
-                size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
-                bytes_read += 3;
-                vd->datablock[y]->size = size_x + (size_y << 8) +
-                    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Get size. */
+		size_x = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
+		bytes_read += 3;
+		vd->datablock[y]->size = size_x + (size_y << 8) +
+		    (size_z << 16);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
 		/* Get string. */
 		vd->datablock[y]->str_len = vd->datablock[y]->size;
@@ -550,20 +556,20 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 
 
 	      case VocBlockTypeRepeat:
-                /* Allocate data block. */
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		/* Allocate data block. */
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
-                /* Get size. */
-                size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
-                bytes_read += 3;
-                vd->datablock[y]->size = size_x + (size_y << 8) +
-                    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Get size. */
+		size_x = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
+		bytes_read += 3;
+		vd->datablock[y]->size = size_x + (size_y << 8) +
+		    (size_z << 16);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
 		/* Get repeat count. */
 		fread(&(vd->datablock[y]->repeat_count), 1, 2, fp);
@@ -572,40 +578,40 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 
 
 	      case VocBlockTypeEndRepeat:
-                /* Allocate data block. */
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		/* Allocate data block. */
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
-                /* Get size. */
-                size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
-                bytes_read += 3;
-                vd->datablock[y]->size = size_x + (size_y << 8) +
-                    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Get size. */
+		size_x = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
+		bytes_read += 3;
+		vd->datablock[y]->size = size_x + (size_y << 8) +
+		    (size_z << 16);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
 		/* There is no info for this field. */
 		break;
 
 
 	      case VocBlockTypeExtended: 
-                /* Allocate data block. */
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		/* Allocate data block. */
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
-                /* Get size. */
-                size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
-                bytes_read += 3;
-                vd->datablock[y]->size = size_x + (size_y << 8) +
-                    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Get size. */
+		size_x = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
+		bytes_read += 3;
+		vd->datablock[y]->size = size_x + (size_y << 8) +
+		    (size_z << 16);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
 		/* Get time constant. */
 		fread(&(vd->datablock[y]->time_constant), 1, 2, fp);
@@ -617,28 +623,28 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 
 		/* Get mode (0 = mono, 1 = stereo). */
 		vd->datablock[y]->mode = (unsigned char)fgetc(fp);
-                bytes_read++;
+		bytes_read++;
 		break;
 
 
-              /* Unknown, assume field is just 1 byte line. */
+	      /* Unknown, assume field is just 1 byte line. */
 	      default:
-                /* Allocate data block. */  
-                y = VocAddDataBlock((voc_data_struct *)vd, type);
-                if(y < 0)
-                    return(VocErrorNoBuffers);
+		/* Allocate data block. */  
+		y = VocAddDataBlock((voc_data_struct *)vd, type);
+		if(y < 0)
+		    return(VocErrorNoBuffers);
 
-                /* Get size. */
-                size_x = (unsigned int)fgetc(fp);
-                size_y = (unsigned int)fgetc(fp);
-                size_z = (unsigned int)fgetc(fp);
-                bytes_read += 3;
-                vd->datablock[y]->size = size_x + (size_y << 8) +
-                    (size_z << 16);
-                /* Set nextseek. */
-                nextseek += (vd->datablock[y]->size + 4);
+		/* Get size. */
+		size_x = (unsigned int)fgetc(fp);
+		size_y = (unsigned int)fgetc(fp);
+		size_z = (unsigned int)fgetc(fp);
+		bytes_read += 3;
+		vd->datablock[y]->size = size_x + (size_y << 8) +
+		    (size_z << 16);
+		/* Set nextseek. */
+		nextseek += (vd->datablock[y]->size + 4);
 
-                break;
+		break;
 	    }
 	}
 
@@ -650,7 +656,7 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 		continue;
 
 	    if( (vd->datablock[x]->type != VocBlockTypeSoundData) &&
-                (vd->datablock[x]->type != VocBlockTypeSoundDataContinue)
+		(vd->datablock[x]->type != VocBlockTypeSoundDataContinue)
 	    )
 		continue;
 
@@ -658,11 +664,11 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
 	}
 
 
-        /* Transfer given fp to the vd structure, the calling
-         * function should not referance it again since we are returning
-         * VocSuccess.
-         */
-        vd->fp = fp;  
+	/* Transfer given fp to the vd structure, the calling
+	 * function should not referance it again since we are returning
+	 * VocSuccess.
+	 */
+	vd->fp = fp;  
 
 	return(VocSuccess);
 }
@@ -679,13 +685,13 @@ int VocReadHeader(const char *filename, FILE *fp, voc_data_struct *vd)
  *      if the requested max_chunk_size is different than data_len.
  */
 int VocReadPartialData(
-        voc_data_struct *vd,
-        off_t offset,
-        off_t max_chunk_size,
-        int read_opt		/* Reading format. */
+	voc_data_struct *vd,
+	off_t offset,
+	off_t max_chunk_size,
+	int read_opt		/* Reading format. */
 )
 {
-        int i, datablock_num;
+	int i, datablock_num;
 	int total_datablocks;
 	voc_block_struct *block_ptr;
 
@@ -695,19 +701,19 @@ int VocReadPartialData(
 	off_t offset_count;
 
 
-        if(vd == NULL)
-            return(VocErrorBadValue);
-        if(offset < 0)
-            return(VocErrorBadValue);
+	if(vd == NULL)
+	    return(VocErrorBadValue);
+	if(offset < 0)
+	    return(VocErrorBadValue);
 
 	/* Read nothing? */
-        if(max_chunk_size <= 0)
+	if(max_chunk_size <= 0)
 	{
 	    free(vd->data);
 	    vd->data = NULL;
 	    vd->data_len = 0;
 
-            return(VocSuccess);
+	    return(VocSuccess);
 	}
 
 	/* Get total_datablocks. */
@@ -729,20 +735,20 @@ int VocReadPartialData(
 	    return(VocErrorNoBuffers);
 	}
 
-        /* Open file as needed. */
-        if(vd->fp == NULL)
-        {
-            off_t filesize;
+	/* Open file as needed. */
+	if(vd->fp == NULL)
+	{
+	    off_t filesize;
 
-            if(vd->filename == NULL)
-                return(VocErrorBadValue);
-         
-            vd->fp = VocOpenFile(vd->filename, "rb", &filesize);
-            if(vd->fp == NULL)
-                return(VocErrorNoAccess);
-            if(filesize == 0)
-                return(VocErrorNoAccess);
-        }
+	    if(vd->filename == NULL)
+		return(VocErrorBadValue);
+	 
+	    vd->fp = VocOpenFile(vd->filename, "rb", &filesize);
+	    if(vd->fp == NULL)
+		return(VocErrorNoAccess);
+	    if(filesize == 0)
+		return(VocErrorNoAccess);
+	}
 
 	/* Go through each data block. */
 	for(datablock_num = 0, tar_buf_pos = 0, offset_count = 0;
@@ -761,7 +767,7 @@ int VocReadPartialData(
 	    if((block_ptr->type != VocBlockTypeSoundData) &&
 	       (block_ptr->type != VocBlockTypeSoundDataContinue)
 	    )
-                continue;
+		continue;
 
 	    /* Skip if offset would not put us in this block. */
 	    if((offset_count + block_ptr->data_len) < offset)
@@ -783,7 +789,7 @@ int VocReadPartialData(
 	    offset_count += block_ptr->data_len;
 	    offset = offset_count;
 	    while((tar_buf_pos < max_chunk_size) &&
-                  (src_buf_pos < block_ptr->data_len)
+		  (src_buf_pos < block_ptr->data_len)
 	    )
 	    {
 		vd->data[tar_buf_pos] = (char)fgetc(vd->fp);
@@ -799,19 +805,19 @@ int VocReadPartialData(
 	    vd->data_len = tar_buf_pos;
 
 
-        /* Shift the DSP data that was read, voc file format stores the
+	/* Shift the DSP data that was read, voc file format stores the
 	 * data as unsigned char.
 	 */
-        switch(read_opt)
-        {
-          case VocReadSigned8:
-            for(i = 0; i < vd->data_len; i++)
-                vd->data[i] = (char)((int)vd->data[i] - (int)128);
-            break;
+	switch(read_opt)
+	{
+	  case VocReadSigned8:
+	    for(i = 0; i < vd->data_len; i++)
+		vd->data[i] = (char)((int)vd->data[i] - (int)128);
+	    break;
 
-          default:
-            break;
-        }
+	  default:
+	    break;
+	}
 
 	return(VocSuccess);
 }
