@@ -29,6 +29,12 @@ int WavReadPartialData(
 );
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Error reporting routine.
  */
@@ -44,7 +50,7 @@ static void WavReportError(
 	{
 	    fprintf(stderr, "%s (Error level %i)", reason, how_bad);
 	}
-        fprintf(stderr, "\n");
+	fprintf(stderr, "\n");
 
 
 	return;
@@ -70,25 +76,25 @@ void WavDestroyData(wav_data_struct *wd)
 	}
 
 	/* Format reading stuff for internal functions only. */
-        wd->format_tag = 0;
+	wd->format_tag = 0;
 
 	/* Header and parms. */
 	wd->header_pos = 0;
 	wd->header_len = 0;
-        wd->channels = 0;
-        wd->samples_per_sec = 0;
-        wd->bytes_per_sec = 0;
-        wd->block_align = 0;
+	wd->channels = 0;
+	wd->samples_per_sec = 0;
+	wd->bytes_per_sec = 0;
+	wd->block_align = 0;
 
 	/* Format specific fields. */
-        wd->bits_per_sample = 0;
-        wd->samples_per_block = 0;
-        wd->coefficients = 0;
-        wd->comp_type = 0;
-        wd->revision = 0;
+	wd->bits_per_sample = 0;
+	wd->samples_per_block = 0;
+	wd->coefficients = 0;
+	wd->comp_type = 0;
+	wd->revision = 0;
 
-        wd->data_starting_pos = 0;
-        wd->data_chunk_size = 0;
+	wd->data_starting_pos = 0;
+	wd->data_chunk_size = 0;
 
 	free(wd->data);
 	wd->data = NULL;
@@ -114,27 +120,27 @@ static FILE *WavOpenFile(
 	    *size_rtn = 0;
 	    return(NULL);
 	}
-        if(mode == NULL)
-        {
-            fprintf(stderr, "%s: Open mode not givin.\n", filename);
-            *size_rtn = 0;
-            return(NULL);
-        }
+	if(mode == NULL)
+	{
+	    fprintf(stderr, "%s: Open mode not givin.\n", filename);
+	    *size_rtn = 0;
+	    return(NULL);
+	}
 
 	if(stat(filename, &stat_buf))
 	{
 	    fprintf(stderr, "%s: No such file.\n", filename);
-            (*size_rtn) = 0;
+	    (*size_rtn) = 0;
 	    return(NULL);
 	}
-        (*size_rtn) = stat_buf.st_size;
+	(*size_rtn) = stat_buf.st_size;
 
 	fp = fopen(filename, mode);
 	if(fp == NULL)
 	{
 	    fprintf(stderr, "%s: Cannot open.\n", filename);
-            (*size_rtn) = 0;
-            return(NULL);
+	    (*size_rtn) = 0;
+	    return(NULL);
 	}
 
 	return(fp);
@@ -148,29 +154,29 @@ static FILE *WavOpenFile(
  */
 int WavIsFPWav(FILE *fp)
 {
-        u_int32_t uix;
-        u_int32_t internal_filesize;
+	u_int32_t uix;
+	u_int32_t internal_filesize;
 
 
-        if(fp == NULL)
-            return(WavErrorNoAccess);
+	if(fp == NULL)
+	    return(WavErrorNoAccess);
 
 	/* Rewind to beginning of file. */
 	rewind(fp);
 
-        /* Check for RIFF ID code. */
-        fread(&uix, 1, 4, fp);
-        if(uix != WavIDRIFF)
-            return(WavErrorNotWave);
+	/* Check for RIFF ID code. */
+	fread(&uix, 1, 4, fp);
+	if(uix != WavIDRIFF)
+	    return(WavErrorNotWave);
 
-        /* Internal filesize. */
-        fread(&internal_filesize, 1, 4, fp);
-        internal_filesize += ftell(fp);
+	/* Internal filesize. */
+	fread(&internal_filesize, 1, 4, fp);
+	internal_filesize += ftell(fp);
 
-        /* Check for Wave ID code. */
-        fread(&uix, 1, 4, fp);
-        if(uix != WavIDWave)
-            return(WavErrorNotWave);
+	/* Check for Wave ID code. */
+	fread(&uix, 1, 4, fp);
+	if(uix != WavIDWave)
+	    return(WavErrorNotWave);
 
 	/* All checks passed, this is a wav file. */
 	return(WavSuccess); 
@@ -185,25 +191,25 @@ int WavIsFPWav(FILE *fp)
 int WavIsFileWav(const char *filename)
 {
 	int status;
-        FILE *fp;
-        off_t filesize;
+	FILE *fp;
+	off_t filesize;
 
 
-        /* Open file. */
-        fp = WavOpenFile(filename, "rb", &filesize);
-        if(fp == NULL)
-            return(WavErrorNoAccess);
-        if(filesize == 0)
+	/* Open file. */
+	fp = WavOpenFile(filename, "rb", &filesize);
+	if(fp == NULL)
+	    return(WavErrorNoAccess);
+	if(filesize == 0)
 	{
 	    fclose(fp);
-            return(WavErrorNoAccess);
+	    return(WavErrorNoAccess);
 	}
 
 	/* Check if file is a wav file. */
 	status = WavIsFPWav(fp);
 
-        /* Close file. */
-        fclose(fp);
+	/* Close file. */
+	fclose(fp);
 
 	return(status);
 }
@@ -226,8 +232,8 @@ int WavReadHeader(const char *filename, FILE *fp, wav_data_struct *wd)
 	u_int16_t usx;
 	u_int32_t uix;
 	u_int32_t nextseek;
-        u_int32_t ckid;
-        u_int32_t cksize;
+	u_int32_t ckid;
+	u_int32_t cksize;
 	u_int32_t ckpos;
 
 	char idstr[5];
@@ -248,7 +254,7 @@ int WavReadHeader(const char *filename, FILE *fp, wav_data_struct *wd)
 	rewind(fp);
 
 
-        /* Reset values. */
+	/* Reset values. */
 	memset(wd, 0x00, sizeof(wav_data_struct));
 
 	/* Get size of file. */
@@ -264,40 +270,40 @@ int WavReadHeader(const char *filename, FILE *fp, wav_data_struct *wd)
 	if(uix != WavIDRIFF)
 	    return(WavErrorNotWave);
 
-        /* Get internal filesize. */
-        fread(&internal_filesize, 1, 4, fp);
-        internal_filesize += ftell(fp);
+	/* Get internal filesize. */
+	fread(&internal_filesize, 1, 4, fp);
+	internal_filesize += ftell(fp);
 
-        /* Check for Wave ID code. */
-        fread(&uix, 1, 4, fp);
-        if(uix != WavIDWave)
-            return(WavErrorNotWave);
+	/* Check for Wave ID code. */
+	fread(&uix, 1, 4, fp);
+	if(uix != WavIDWave)
+	    return(WavErrorNotWave);
 
 
 	/* Begin reading wav file header. */
 
-        /* Record file name. */
-        if(filename != NULL)
-            wd->filename = strdup(filename);
+	/* Record file name. */
+	if(filename != NULL)
+	    wd->filename = strdup(filename);
 
 
 	/* Begin reading chunks. */
 
-        nextseek = ftell(fp);
+	nextseek = ftell(fp);
 	chunk_count = 0;
 	while(nextseek < internal_filesize)
 	{
 	    fseek(fp, nextseek, SEEK_SET);
-            fread(&ckid, 1, 4, fp);
-            fread(&cksize, 1, 4, fp);
+	    fread(&ckid, 1, 4, fp);
+	    fread(&cksize, 1, 4, fp);
 	    ckpos = ftell(fp);
-            nextseek = cksize + ckpos;
-            memcpy(idstr, (void *)&ckid, 4);
-            idstr[4] = '\0';
+	    nextseek = cksize + ckpos;
+	    memcpy(idstr, (void *)&ckid, 4);
+	    idstr[4] = '\0';
 
 	    /* Check chunk ID. */
-            switch(ckid)
-            {
+	    switch(ckid)
+	    {
 	      /* Format (header?) chunk. */
 	      case WavFormatChunkCode:
 
@@ -354,51 +360,51 @@ int WavReadHeader(const char *filename, FILE *fp, wav_data_struct *wd)
 
 			break;
 
-                      case 0x0011: /* WAVE_FORMAT_DVI_ADPCM??? */
+		      case 0x0011: /* WAVE_FORMAT_DVI_ADPCM??? */
 			/* Assuming same as WAVE_FORMAT_DSPGROUP_TRUESPEECH. */
 
 		      case 0x0022: /* WAVE_FORMAT_DSPGROUP_TRUESPEECH */
-                        /* Get samples per block. */
-                        fread(&usx, 1, 2, fp);
-                        wd->samples_per_block = usx;
+			/* Get samples per block. */
+			fread(&usx, 1, 2, fp);
+			wd->samples_per_block = usx;
 
 			break;
 
-                      case 0x0021:  /* WAVE_FORMAT_SONARC */
+		      case 0x0021:  /* WAVE_FORMAT_SONARC */
 			/* Get compression type. */
-                        fread(&usx, 1, 2, fp);
-                        wd->comp_type = usx;
+			fread(&usx, 1, 2, fp);
+			wd->comp_type = usx;
 
-                        break;
-                      case 0x0200: /* WAVE_FORMAT_CREATIVE_ADPCM */
+			break;
+		      case 0x0200: /* WAVE_FORMAT_CREATIVE_ADPCM */
 			/* Get revision. */
 			fread(&usx, 1, 2, fp);
 			wd->revision = usx;
 
-                        break;
+			break;
 
 		    }
 		}    /* End format specific fields. */
 		break;
 
 
-              /* Data chunk. */
-              case WavDataChunkCode:
+	      /* Data chunk. */
+	      case WavDataChunkCode:
 		/* Record data chunk position and size. */
 		wd->data_starting_pos = (off_t)ckpos;
-                wd->data_chunk_size = (off_t)cksize;
+		wd->data_chunk_size = (off_t)cksize;
 		break;
 
 
-              /* Unknown chunk. */
-              default:
+	      /* Unknown chunk. */
+	      default:
 /*
-                fprintf(stderr,
+		fprintf(stderr,
 		    "%s: Chunk %i: Unknown chunk ID 0x%.8x.\n",
 		    filename, chunk_count, ckid
 		);
  */
-                break;
+		break;
 
 	    }        /* End check chunk ID. */
 
@@ -429,9 +435,9 @@ int WavReadHeader(const char *filename, FILE *fp, wav_data_struct *wd)
  *	if the requested max_chunk_size is different than wd->data_len.
  */
 int WavReadPartialData(
-        wav_data_struct *wd,
-        long offset,            /* In bytes. */
-        long max_chunk_size,    /* In bytes. */
+	wav_data_struct *wd,
+	long offset,            /* In bytes. */
+	long max_chunk_size,    /* In bytes. */
 	int read_opt		/* Reading format. */
 )
 {
@@ -439,17 +445,17 @@ int WavReadPartialData(
 	char *buf_ptr;
 
 
-        if(wd == NULL)
-            return(WavErrorBadValue);
+	if(wd == NULL)
+	    return(WavErrorBadValue);
 	if(offset < 0)
 	    return(WavErrorBadValue);
 
 	/* Read nothing? */
 	if(max_chunk_size <= 0)
 	{
-            free(wd->data);
-            wd->data = NULL;
-            wd->data_len = 0;
+	    free(wd->data);
+	    wd->data = NULL;
+	    wd->data_len = 0;
 
 	    return(WavSuccess);
 	}
@@ -466,11 +472,11 @@ int WavReadPartialData(
 	}
 	if(max_chunk_size <= 0)
 	{
-            return(WavErrorEndOfData);
+	    return(WavErrorEndOfData);
 	}
 
 
-        /* Open file as needed. */
+	/* Open file as needed. */
 	if(wd->fp == NULL)
 	{
 	    off_t filesize;
@@ -478,8 +484,8 @@ int WavReadPartialData(
 	    if(wd->filename == NULL)
 		return(WavErrorBadValue);
 
-            wd->fp = WavOpenFile(wd->filename, "rb", &filesize);
-            if(wd->fp == NULL)
+	    wd->fp = WavOpenFile(wd->filename, "rb", &filesize);
+	    if(wd->fp == NULL)
 		return(WavErrorNoAccess);
 	    if(filesize == 0)
 		return(WavErrorNoAccess);
@@ -517,14 +523,14 @@ int WavReadPartialData(
 	{
 	  /* Shift byte value by - 128 to make it signed 8. */
 	  case WavReadSigned8:
-            for(i = 0; i < max_chunk_size; i++)
-                *buf_ptr++ = (char)(fgetc(wd->fp) - 128);
+	    for(i = 0; i < max_chunk_size; i++)
+		*buf_ptr++ = (char)(fgetc(wd->fp) - 128);
 	    break;
 
 	  /* Read data as is (unsigned 8). */
 	  default:
-            for(i = 0; i < max_chunk_size; i++)
-                *buf_ptr++ = (char)(fgetc(wd->fp));
+	    for(i = 0; i < max_chunk_size; i++)
+		*buf_ptr++ = (char)(fgetc(wd->fp));
 	    break;
 	}
 
