@@ -20,14 +20,20 @@ void ConnectionDeleteAll();
 void ConnectionReclaim(void);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Checks if connection n is valid.
  */
 int ConnectionIsAllocated(int n)
 {
 	if((n < 0) ||
-           (n >= total_yconnections) ||
-           (yconnection == NULL)
+	   (n >= total_yconnections) ||
+	   (yconnection == NULL)
 	)
 	    return(0);
 	else if(yconnection[n] == NULL)
@@ -168,7 +174,7 @@ void ConnectionReset(int n)
 	con_ptr->buf_len = 0;
 
 	con_ptr->user_id = 0;
-        con_ptr->group_id = 0;
+	con_ptr->group_id = 0;
 
 	con_ptr->access_level = 0;
 
