@@ -1,14 +1,15 @@
 /*
-	Network connections.
+	Network connection structure.
+
+	Stores information about each connection to the server.
  */
 
 #ifndef YCONNECTION_H
 #define YCONNECTION_H
 
+#include <sys/types.h>
 #include "ytypes.h"
 
-
-
 typedef struct {
 
 	/* Primary transfer socket, -1 means not connected. */
@@ -42,9 +43,6 @@ extern YConnection **yconnection;
 extern int total_yconnections;
 
 
-/*
- *	Functions:
- */
 extern int ConnectionIsAllocated(int n);
 extern int ConnectionIsConnected(int n);
 extern YConnection *ConnectionGetPtr(int n);
