@@ -1,17 +1,12 @@
 /*
-                     Y I F F   S O U N D   S E R V E R
-
-
-              Copyright (C) 1997-2001 WolfPack Entertainment
+	YIFF Sound Server
 
+	Copyright (C) 1997-2003 WolfPack Entertainment
  */
 
 #ifndef YIFF_H
 #define YIFF_H
 
-#include <stdio.h>
-#include <time.h>
-#include <sys/time.h>
 #include <sys/types.h>
 
 #include "ytypes.h"
@@ -29,15 +24,16 @@
  *	Program name and version:
  */
 #define PROG_NAME	"YIFF"
-#define PROG_VERSION	"2.12.4"
+#define PROG_VERSION	"2.14.2"
 
 #define PROG_VERSION_MAJOR	2
-#define PROG_VERSION_MINOR	12
+#define PROG_VERSION_MINOR	14
+#define PROG_VERSION_RELEASE	2
 
 #define PROG_VENDOR_NAME	"WolfPack Entertainment"
 
 #define YPROTOCOL_VERSION_MAJOR	2
-#define YPROTOCOL_VERSION_MINOR	12
+#define YPROTOCOL_VERSION_MINOR	14
 
 /*
  *	Program help message:
@@ -89,7 +85,7 @@ Usage: yiff [config_file] [options]\n\
  *	Copyright mesg:
  */
 #define PROG_COPYRIGHT "\
-Copyright (C) 1997-2001 WolfPack Entertainment.\n\
+Copyright (C) 1997-2003 WolfPack Entertainment.\n\
 This program is protected by international copyright laws and treaties,\n\
 distribution and/or modification of this software in violation of the\n\
 GNU Public License is strictly prohibited. Violators will be prosicuted\n\
