@@ -5,13 +5,11 @@
 #ifndef YSOUND_H
 #define YSOUND_H
 
-#include <stdio.h>
-#include <time.h>
-
+#include <sys/types.h>
 #include "ytypes.h"
 #include "ytiming.h"
 #include "midiiow.h"
-
+#include "audiocd.h"
 
 /*
  *	Audio play direction:
@@ -37,16 +35,23 @@
  */
 typedef struct {
 
-	/*   Midway buffer, it is publically modifyable.
+	/* Midway buffer, it is publically modifyable.
 	 *
-	 *   Note: If the recorder audio's sample_size is set to 16
-	 *   then the limit of this buffer should be (buffer_length / 2)
-	 *   and the call to YSoundPlayBuffer() will automatically
-	 *   expand buffer when it coppies it to device_buffer.
+	 * Note: If the recorder audio's sample_size is set to 16
+	 * then the limit of this buffer should be (buffer_length / 2)
+	 * and the call to YSoundPlayBuffer() will automatically
+	 * expand buffer when it coppies it to device_buffer.
+	 *
+	 * If YSHM_SUPPORT is defined, then this buffer is a shared
+	 * memory segment and needs to be managed with SHMNew() and
+	 * SHMUnref() instead of calloc() and free().
 	 */
 	SoundBuffer	*buffer;
 	YDataLength	buffer_length,
 			buffer_content_length;
+#ifdef YSHM_SUPPORT
+	int buffer_shm_id;	/* Garbage if buffer is NULL. */
+#endif
 
 	/* Devices's buffer, private.  Do not read or write it! */
 	SoundBuffer	*device_buffer;
@@ -129,11 +134,11 @@ typedef struct {
 
 
 #ifdef OSS_BUFFRAG
-        /*   Buffer fragmentings (this is Linux specific). It was
+	/*   Buffer fragmentings (this is Linux specific). It was
 	 *   was introduced so that games could play sound at
 	 *   better timings.
 	 */
-        Boolean	allow_fragments;
+	Boolean	allow_fragments;
 
 	u_int8_t num_fragments;
 	u_int8_t fragment_size;	/* OS Native units, not bytes. */
@@ -169,15 +174,18 @@ typedef struct {
 	 * the above mixer.
 	 */
 
+	/* Name of the Sound device. */
+	char *sound_name;
 
 	/* Marks if the Audio is currently shelled out if True. */
 	Boolean shelled_out;
 
-	/* MIDI IO wrapper settings and resources, see
-	 * midiiow.h for declarations.
-	 */
+	/* MIDI IO wrapper settings and resources, see midiiow.h. */
 	MIDIAudio midi_audio;
 
+	/* Audio CD wrapper context, see audiocd.h. */
+	AudioCDContext *audiocd_context;
+
 } Audio;
 
 
