@@ -1,35 +1,20 @@
 #ifndef YTIMING_H
 #define YTIMING_H
 
-#include <unistd.h>  
-
-#include <time.h>
-#include <sys/time.h>
-
+#include <sys/types.h>
 
 typedef struct {
-
 	time_t	ms,
 		us;	/* microseconds component, 0 to 1000. */
-
 } YDeltaTime;
 
-
 typedef struct {
-
 	time_t	ms,
 		us;     /* microseconds component, 0 to 1000. */
-
 } YTime;
 
-
-/*
- *	Functions:
- */
 extern void GetCurrentTime(YTime *t);
-
 extern time_t MilliTime(void);
 extern time_t UTime(void);
 
-
 #endif	/* YTIMING_H */
