@@ -1,8 +1,6 @@
 #ifndef YTYPES_H
 #define YTYPES_H
 
-
-#include <stdio.h>
 #include <limits.h>
 #include <sys/types.h>
 
@@ -12,7 +10,6 @@
 #include "../include/Y2/Y.h"
 
 
-
 /*
  *	Sound buffer type:
  */
@@ -39,10 +36,10 @@ typedef YID PlayStackID;
  */
 typedef struct {
 
-        /* Coefficient = (val / ((u_int16_t)-1)) */
+	/* Coefficient = (val / ((u_int16_t)-1)) */
 
-        u_int16_t       left,
-                        right;
+	u_int16_t	left, right,
+			back_left, back_right;
 
 } YVolumeStruct;
 
