@@ -19,6 +19,12 @@ extern int h_errno;
 static void print_help(void);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Prints help message.
  */
@@ -46,16 +52,16 @@ Usage: yhost [-] <address> [options]\n\
         3       Systems error.\n\
 \n"
 	);
-
-	return;
 }
 
 
 int main(int argc, char *argv[])
 {
 	int i, status;
+	const char *arg_ptr;
+
 	const char *con_arg = NULL;
-	int is_add_host = 1;
+	Boolean is_add_host = True;
 
 	YConnection *con = NULL;
 	YIPUnion ip;
@@ -74,52 +80,56 @@ int main(int argc, char *argv[])
 	/* Parse arguments. */
 	for(i = 1; i < argc; i++)
 	{
-	    if(argv[i] == NULL)
+	    arg_ptr = argv[i];
+	    if(arg_ptr == NULL)
 		continue;
 
 	    /* Help. */
-	    if(strcasepfx(argv[i], "--h") ||
-               strcasepfx(argv[i], "-h") ||
-               !strcmp(argv[i], "?")
+	    if(strcasepfx(arg_ptr, "--h") ||
+               strcasepfx(arg_ptr, "-h") ||
+               !strcmp(arg_ptr, "?")
 	    )
 	    {
 		print_help();
 		return(0);
 	    }
             /* Connect address. */
-            if(strcasepfx(argv[i], "--rec") ||
-               strcasepfx(argv[i], "-rec")
+            if(strcasepfx(arg_ptr, "--rec") ||
+               strcasepfx(arg_ptr, "-rec")
             )
             {
                 i++;
-                if(i < argc)
+		arg_ptr = (i < argc) ? argv[i] : NULL;
+		if(arg_ptr != NULL)
                 {
-                    con_arg = argv[i];
+                    con_arg = arg_ptr;
                 }
                 else
                 {
-                    fprintf(stderr,
+                    fprintf(
+			stderr,
                         "%s: Requires argument.\n",
                         argv[i - 1]
                     );
+		    continue;
                 }
             }
 	    /* Add or remove? */
 	    if(i == 1)
 	    {
-		if(!strcmp(argv[i], "-"))
+		if(!strcmp(arg_ptr, "-"))
 		{
-		    is_add_host = 0;
+		    is_add_host = False;
 		    continue;
 		}
-		else if(!strcmp(argv[i], "+"))
+		else if(!strcmp(arg_ptr, "+"))
 		{
-		    is_add_host = 1;
+		    is_add_host = True;
                     continue;
 		}
 		else
 		{
-		    is_add_host = 1;
+		    is_add_host = True;
 		}
 	    }
 	    /* Address. */
@@ -128,36 +138,40 @@ int main(int argc, char *argv[])
             )
 	    {
 		/* Parse and resolve address. */
-		he = gethostbyname(argv[i]);
+		he = gethostbyname(arg_ptr);
 		if(he == NULL)
 		{
 		    switch(h_errno)
 		    {
                       case NO_ADDRESS:
-                        fprintf(stderr,
+                        fprintf(
+			    stderr,
                             "%s: No associated IP address.\n",
-                            argv[i]
+                            arg_ptr
                         );
                         break;
 
                       case NO_RECOVERY:
-                        fprintf(stderr,
+                        fprintf(
+			    stderr,
                             "%s: Unrecoverable error.\n",
-                            argv[i]
+                            arg_ptr
                         );
                         break;
 
                       case TRY_AGAIN:
-                        fprintf(stderr,
+                        fprintf(
+			    stderr,
                             "%s: Name server unavailable.\n",
-                            argv[i]
+                            arg_ptr
                         );
                         break;
 
                       default:
-                        fprintf(stderr,
+                        fprintf(
+			    stderr,
                             "%s: Unknown host.\n",
-                            argv[i]
+                            arg_ptr
                         );
                         break;
 		    }
