@@ -12,20 +12,25 @@
 static void print_help(void);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Prints help message.
  */
 static void print_help(void)
 {
 	printf("\
-Usage: ymixer [mixer] [value1] [value2] [options]\n\
+Usage: ymixer [mixer] [value1] [value2] [value3] [value4] [options]\n\
 \n\
     [mixer] specifies the mixer channel device name, running without\n\
-    any arguments prints a list of available mixer names.
+    any arguments prints a list of available mixer names.\n\
 \n\
-    [value1] and [value2] specify the percent values in the domain\n\
-    of [0.0%%, 100.0%%] to be set (decimals allowed). If neither is\n\
-    specified then the current value is printed.\n\
+    [value#] specify the percent values (from 0.0%%, 100.0%%) to be set.\n\
+    If no [value#] is specified then the current value is printed.\n\
 \n\
     [options] can be any of the following:\n\
 \n\
@@ -39,8 +44,6 @@ Usage: ymixer [mixer] [value1] [value2] [options]\n\
         3       Systems error.\n\
 \n"
 	);
-
-	return;
 }
 
 
@@ -55,11 +58,14 @@ int main(int argc, char *argv[])
 	int mixer_code = 0;
 	int mixer_num = 0;
 
-	int got_values = 0;
-	Coefficient value1 = 0.0, value2 = 0.0;
+	Boolean got_value[YMixerValues];
+	Coefficient val[YMixerValues];
 	char *mixer_name[] = YMixerConicalNames;
 
 
+	memset(got_value, False, YMixerValues * sizeof(Boolean));
+
+
 	/* Parse arguments. */
 	for(i = 1; i < argc; i++)
 	{
@@ -115,17 +121,30 @@ int main(int argc, char *argv[])
 		    }
 		}
 	    }
+	    /* Subsequent arguments are mixer channel values. */
             /* Value 1. */
             else if(i == 2)
             {
-		value1 = atof(argv[i]);
-		got_values = 1;		/* Mark that we got value(s). */
+		val[0] = atof(argv[i]);
+		got_value[0] = True;
             }
             /* Value 2. */
             else if(i == 3)
             {
-                value2 = atof(argv[i]);
-		got_values = 1;		/* Mark that we got value(s). */
+                val[1] = atof(argv[i]);
+		got_value[1] = True;
+            }
+            /* Value 3. */
+            else if(i == 4)
+            {
+                val[2] = atof(argv[i]);
+                got_value[2] = True;
+            }
+            /* Value 4. */
+            else if(i == 5)
+            {
+                val[3] = atof(argv[i]);
+                got_value[3] = True;
             }
 	}
 
@@ -150,14 +169,16 @@ int main(int argc, char *argv[])
 	 * values were given on the command line then got_values
 	 * will be false.
 	 */
-	if(got_values)
+	if(got_value[0])
 	{
 	    /* We have values, so set them. */
-	    if(YSetMixerChannel(
+	    if(YSetMixerChannelQuad(
 		con,
 		mixer_code,
-		(Coefficient)(value1 / 100),
-		(Coefficient)(value2 / 100)
+		(((YMixerValues > 0) && got_value[0]) ? val[0] : 0.0) / 100.0,
+                (((YMixerValues > 1) && got_value[1]) ? val[1] : val[0]) / 100.0,
+                (((YMixerValues > 2) && got_value[2]) ? val[2] : val[0]) / 100.0,
+                (((YMixerValues > 3) && got_value[3]) ? val[3] : val[0]) / 100.0
 	    ))
 		fprintf(
 		    stderr,
@@ -188,9 +209,9 @@ int main(int argc, char *argv[])
 		    mixer_num = i;
 
 		    /* Get mixer values for this mixer code. */
-		    if(YGetMixerChannel(
+		    if(YGetMixerChannelQuad(
 			con, mixer_code,
-			&value1, &value2
+			&val[0], &val[1], &val[2], &val[3]
 		    ))
 			printf(
 			    "%s: Cannot obtain values.\n",
@@ -198,9 +219,10 @@ int main(int argc, char *argv[])
 			);
 		    else
 			printf(
-			    "%s: %.1f%% %.1f%%\n",
+			    "%s: %.1f%% %.1f%% %.1f%% %.1f%%\n",
 			    mixer_name[mixer_num],
-			    (float)(value1 * 100), (float)(value2 * 100)
+			    (float)(val[0] * 100), (float)(val[1] * 100),
+			    (float)(val[2] * 100), (float)(val[3] * 100)
 			);
 		}
 	    }
@@ -215,9 +237,9 @@ int main(int argc, char *argv[])
 		    mixer_num = 0;
 
                 /* Get mixer values. */
-                if(YGetMixerChannel(
+                if(YGetMixerChannelQuad(
                     con, mixer_code,
-                    &value1, &value2
+                    &val[0], &val[1], &val[2], &val[3]
                 ))
                     printf(
                         "%s: Cannot obtain values.\n",
@@ -225,9 +247,10 @@ int main(int argc, char *argv[])
                     );
                 else
                     printf(
-                        "%s: %.1f%% %.1f%%\n",
+                        "%s: %.1f%% %.1f%% %.1f%% %.1f%%\n",
                         mixer_name[mixer_num],
-                        (float)(value1 * 100), (float)(value2 * 100)
+			(float)(val[0] * 100), (float)(val[1] * 100),
+			(float)(val[2] * 100), (float)(val[3] * 100)
                     );
 	    }
 	}
