@@ -15,10 +15,15 @@
 static void handle_signal(int s);
 static void print_help(void);
 
+static Boolean interrupted;
+static Boolean verbose;
+static Boolean allow_change_mode;
 
-static int interrupted;
-static int verbose;
-static int allow_change_mode;
+
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
 
 
 /*
@@ -28,23 +33,29 @@ static void handle_signal(int s)
 {
 	switch(s)
 	{
+#ifdef SIGINT
 	  case SIGINT:
-	    signal(SIGINT, handle_signal);
-	    interrupted = 1;
+	    interrupted = True;
 	    break;
-
+#endif
+#ifdef SIGTERM
 	  case SIGTERM:
-            signal(SIGTERM, handle_signal);
-            interrupted = 1;
+            interrupted = True;
             break; 
-
+#endif
+#ifdef SIGPIPE
           case SIGPIPE:
-            signal(SIGPIPE, handle_signal);
-            interrupted = 1;
             break;
+#endif
+#ifdef SIGHUP
+          case SIGHUP:
+            break;
+#endif
+#ifdef SIGCONT
+          case SIGCONT:
+            break;
+#endif
 	}
-
-	return;
 }
 
 
@@ -80,19 +91,20 @@ Usage: yplay [options] <file1> [file2] ...\n\
         3       Systems error.\n\
 \n"
 	);
-
-	return;
 }
 
 
 
 int main(int argc, char *argv[])
 {
-	int i, n, playing;
-	long cycle;
+	int i;
+	const char *arg_ptr;
 
 	const char *con_arg = NULL;
 
+	Boolean playing;
+	long cycle;
+
 	int total_repeats = 1;
 	char **file = NULL;
 	int total_files = 0;
@@ -111,16 +123,30 @@ int main(int argc, char *argv[])
 
 
 	/* Reset globals. */
-	interrupted = 0;
-	verbose = 0;
-	allow_change_mode = 0;
+	interrupted = False;
+	verbose = False;
+	allow_change_mode = False;
 
 	/* Set up signals to watch for. */
+#ifdef SIGINT
 	signal(SIGINT, handle_signal);
-        signal(SIGPIPE, handle_signal);
+#endif
+#ifdef SIGTERM
         signal(SIGTERM, handle_signal);
+#endif
+#ifdef SIGPIPE
+        signal(SIGPIPE, handle_signal);
+#endif
+#ifdef SIGHUP
+	signal(SIGHUP, handle_signal);
+#endif
+#ifdef SIGCONT
+        signal(SIGCONT, handle_signal);
+#endif
 
-	/* Not enough arguments? */
+	/* If there are not enough arguments given then print the help
+	 * message.
+	 */
 	if(argc < 2)
 	{
 	    print_help();
@@ -130,122 +156,137 @@ int main(int argc, char *argv[])
 	/* Parse arguments. */
 	for(i = 1; i < argc; i++)
 	{
-	    if(argv[i] == NULL)
+	    arg_ptr = argv[i];
+	    if(arg_ptr == NULL)
 		continue;
 
 	    /* Help. */
-	    if(strcasepfx(argv[i], "--h") ||
-               strcasepfx(argv[i], "-h") ||
-               !strcmp(argv[i], "?")
+	    if(strcasepfx(arg_ptr, "--h") ||
+               strcasepfx(arg_ptr, "-h") ||
+               !strcmp(arg_ptr, "?")
 	    )
 	    {
 		print_help();
 		return(0);
 	    }
 	    /* Connect address. */
-	    else if(strcasepfx(argv[i], "--rec") ||
-                    strcasepfx(argv[i], "-rec")
+	    else if(strcasepfx(arg_ptr, "--rec") ||
+                    strcasepfx(arg_ptr, "-rec")
 	    )
 	    {
 		i++;
-		if(i < argc)
+		arg_ptr = (i < argc) ? argv[i] : NULL;
+		if(arg_ptr != NULL)
 		{
-		    con_arg = argv[i];
+		    con_arg = arg_ptr;
 		}
 		else
 		{
-		    fprintf(stderr,
+		    fprintf(
+			stderr,
 			"%s: Requires argument.\n",
 			argv[i - 1]
 		    );
+                    continue;
 		}
 	    }
 	    /* Repeat. */
-            else if(!strcasecmp(argv[i], "-r"))
+            else if(!strcasecmp(arg_ptr, "-r"))
             {
                 i++;
-                if(i < argc)
+                arg_ptr = (i < argc) ? argv[i] : NULL;
+                if(arg_ptr != NULL)
                 {
-		    total_repeats = atoi(argv[i]);
+		    total_repeats = atoi(arg_ptr);
                     if(total_repeats == 0)
-                        fprintf(stderr,
-                             "%s: Value must be non-zero.\n",
+                        fprintf(
+			    stderr,
+                            "%s: Warning: Value must be non-zero.\n",
                             argv[i - 1]
                         );
 		}
 		else
 		{
-                    fprintf(stderr,
-                        "%s: Requires argument.\n",
-                        argv[i - 1]
+                    fprintf(
+			stderr,
+			"%s: Requires argument.\n",
+			argv[i - 1]
                     );
+		    continue;
 		}
             }
             /* Change mode. */
-            else if(!strcasecmp(argv[i], "-m"))
+            else if(!strcasecmp(arg_ptr, "-m"))
             {
-                allow_change_mode = 1;
+                allow_change_mode = True;
             }
 	    /* Volume. */
 	    else if(!strcasecmp(argv[i], "-vol"))
             {
 		i++;
-                if(i < argc)
+                arg_ptr = (i < argc) ? argv[i] : NULL;
+                if(arg_ptr != NULL)
                 {
-                    vol_left = atof(argv[i]);
+                    vol_left = atof(arg_ptr);
                 }
                 else
                 {
-                    fprintf(stderr,
-                        "%s: Requires 2 arguments.\n",
+                    fprintf(
+			stderr,
+                        "%s: Requires at least 2 arguments.\n",
                         argv[i - 1]
                     );
+		    continue;
                 }
 
                 i++;
-                if(i < argc)
+                arg_ptr = (i < argc) ? argv[i] : NULL;
+                if(arg_ptr != NULL)
                 {
-                    vol_right = atof(argv[i]);
+                    vol_right = atof(arg_ptr);
                 }
                 else
                 {
-                    fprintf(stderr,
-                        "%s: Requires 2 arguments.\n",
+                    fprintf(
+			stderr,
+                        "%s: Requires at least 2 arguments.\n",
                         argv[i - 1]
                     );
+		    continue;
                 }
             }
 	    /* Applied sample rate. */
-            else if(!strcasecmp(argv[i], "-s"))
+            else if(!strcasecmp(arg_ptr, "-s"))
             {
                 i++;
-                if(i < argc)
+                arg_ptr = (i < argc) ? argv[i] : NULL;
+                if(arg_ptr != NULL)
                 {   
-                    applied_sample_rate = atoi(argv[i]);
+                    applied_sample_rate = MAX(atoi(arg_ptr), 0);
                 }
 		else
                 {
-                    fprintf(stderr,
+                    fprintf(
+			stderr,
                         "%s: Requires argument.\n",
                         argv[i - 1]
                     );
+		    continue;
                 }
-		if(applied_sample_rate < 0)
-		    applied_sample_rate = 0;
 	    }
             /* Verbose. */
-            else if(!strcasecmp(argv[i], "-v"))
+            else if(!strcasecmp(arg_ptr, "-v"))
             {
-                verbose = 1;
+                verbose = True;
             }
 	    /* All else assume argument to be a file. */
-	    else
+	    else if((*arg_ptr != '\0') &&
+                    (*arg_ptr != '-') &&
+                    (*arg_ptr != '+')
+	    )
 	    {
-		if(total_files < 0)
-		    total_files = 0;
-
-		n = total_files;
-		total_files++;
+		int n = total_files;
+		total_files = n + 1;
 
 		file = (char **)realloc(
 		    file,
@@ -256,8 +297,10 @@ int main(int argc, char *argv[])
 		    total_files = 0;
 		    continue;
 		}
-
-		file[n] = StringCopyAlloc(argv[i]);
+		else
+		{
+		    file[n] = strdup(arg_ptr);
+		}
 	    }
 	}
 
@@ -287,7 +330,7 @@ int main(int argc, char *argv[])
 
 
 	/* Begin playing. */
-	if(1)
+	if(True)
 	{
 	    /* Warn if repeating infinatly. */
 	    if(total_repeats < 0)
@@ -416,7 +459,7 @@ int main(int argc, char *argv[])
                     switch(au_stats.format)
                     {
                       case SndObjTypeDSP:
-                        fprintf(stdout,
+                        printf(
 "ID: %ld  Type: DSP  SmpRate: %i Hz  Bits: %i  Ch: %i  %s\n",
                             play_id,
                             au_stats.sample_rate,
@@ -427,7 +470,7 @@ int main(int argc, char *argv[])
                         break;
                      
                       case SndObjTypeMIDI:
-                        fprintf(stdout,
+                        printf(
  "ID: %ld  Type: MIDI  %s\n",
                             play_id,
                             tmp_path
@@ -435,7 +478,7 @@ int main(int argc, char *argv[])
                         break;
                         
                       default:
-                        fprintf(stdout,
+                        printf(
  "ID: %ld  Type: *Unknown*  %s\n",
                             play_id,
                             tmp_path
@@ -444,7 +487,7 @@ int main(int argc, char *argv[])
                 }
 
 		/* Wait untill audio is done playing. */
-		playing = 1;
+		playing = True;
 		while(playing && !interrupted)
 		{
 		    if(YGetNextEvent(
@@ -459,7 +502,7 @@ int main(int argc, char *argv[])
 			    if(event.kill.yid == play_id)
 			    {
 				/* Current sound object no longer playing. */
-			        playing = 0;
+			        playing = False;
 			    }
 			    else
 			    {
@@ -484,10 +527,10 @@ int main(int argc, char *argv[])
 			    /* Consider disconnect/shutdown as an
 			     * interrupt.
 			     */
-			    interrupted = 1;
+			    interrupted = True;
 
 			    /* Current sound object no longer playing. */
-			    playing = 0;
+			    playing = False;
 
 			    /* Connection structure needs to be closed. */
 			    YCloseConnection(con, False);
@@ -505,7 +548,6 @@ int main(int argc, char *argv[])
 		{
 		    if(verbose)
 		        printf("Playback interrupted.\n");
-
 		    break;
 		}
 	    }
