@@ -1,6 +1,8 @@
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
+#include <sys/types.h>
+#include <time.h>
 #include <unistd.h>
 
 #include "../include/Y2/Y.h"
@@ -12,6 +14,12 @@
 static void print_help(void);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *	Print help.
  */
@@ -33,8 +41,6 @@ Usage: yrecinfo [options]\n\
         3       Systems error.\n\
 \n"
 	);
-
-	return;
 }
 
 
@@ -43,12 +49,13 @@ int main(int argc, char *argv[])
 	int i, total;
 	int print_audio_modes = 0;
 	const char *con_arg = NULL;
-
+	unsigned long cur_time;
 	YConnection *con = NULL;
 	YEventAudioStats astats;
 	YEventServerStats sstats;
 	YAudioModeValuesStruct **audio_mode, *audio_mode_ptr;
 
+	tzset();
 
 	/* Parse arguments. */
 	for(i = 1; i < argc; i++)
@@ -111,6 +118,10 @@ int main(int argc, char *argv[])
         }
 
 
+	/* Get current time. */
+	cur_time = time(NULL);
+
+
 	/* Begin requesting and printing stats. */
 
 	/* Print recorder address. */
@@ -123,6 +134,20 @@ int main(int argc, char *argv[])
 	/* Server stats. */
 	if(!YGetServerStats(con, &sstats))
 	{
+	    unsigned long uptime = cur_time - sstats.start_time;
+
+            printf("vendor name: \"%s\"\n",
+                sstats.vendor_name
+            );
+
+            printf("server name: \"%s\"\n",
+                sstats.server_name
+            );
+
+            printf("sound name: \"%s\"\n",
+                sstats.sound_name
+            );
+
             printf("version: %i.%i\n",
                 sstats.protocol_version_major,
 		sstats.protocol_version_minor
@@ -132,6 +157,12 @@ int main(int argc, char *argv[])
                 (float)(sstats.cycle_load * 100)
             );
 
+            printf("uptime: %.2i:%.2i:%.2i\n",
+                    (int)(uptime / 3600),
+                    (int)((uptime / 60) % 60),
+                    (int)(uptime % 60)
+	    );
+
             printf("maximum protocol statement: %i bytes\n",
                 YNetRecvBufLen
             );
@@ -161,8 +192,10 @@ int main(int argc, char *argv[])
             printf("sample rate: %i Hz\n",
                 astats.sample_rate
             );
-            printf("channels: %i\n",
-                astats.channels
+            printf("channels: %i (%s)\n",
+                astats.channels,
+		(astats.channels == 4) ? "quad" :
+		    ((astats.channels == 2) ? "stereo" : "mono")
             );
             printf("sample size: %i bits\n",
                 astats.sample_size
