@@ -11,9 +11,7 @@
 static void print_help(void);
 
 
-/*
- *	Setting parameter codes:
- */
+/* Parameter codes to determine what we need to set. */
 #define PARM_NONE		0	/* Do nothing. */
 #define PARM_CYCLE		1	/* Change cycle. */
 #define PARM_AUDIO_PRESET	2	/* Change Audio mode preset. */
@@ -21,6 +19,12 @@ static void print_help(void);
 #define PARM_AUDIO_SHELLOUT	4	/* Shell out recorder. */
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *      Prints help message.
  */
@@ -56,8 +60,6 @@ Usage: yset <parameter [value...]> [options]\n\
         3       Systems error.\n\
 \n"
 	);
-
-	return;
 }
 
 
