@@ -11,6 +11,12 @@
 static void print_help(void);
 
 
+#define MIN(a,b)        ((a) < (b) ? (a) : (b))
+#define MAX(a,b)        ((a) > (b) ? (a) : (b))
+#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
+#define ABSOLUTE(x)     (((x) < 0) ? ((x) * -1) : (x))
+
+
 /*
  *      Prints help message.
  */
@@ -31,8 +37,6 @@ Usage: yshutdown [options]\n\
         3       Systems error.\n\
 \n"
 	);
-
-	return;
 }
 
 
